/*
    <one line to give the program's name and a brief idea of what it does.>
    Copyright (C) 2010  Rico Rommel

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

*/

#ifndef CONFIGDIALOG_H
#define CONFIGDIALOG_H

#include "ui_configdialog.h"
#include <QSqlDatabase>
#include <QSqlRecord>
#include <QSqlQuery>
#include "inputdialog.h"
#include "types.h"


class ConfigDialog : public KDialog
{
  Q_OBJECT
  public:
    ConfigDialog(QWidget *parent);
    ~ConfigDialog();
    void setHostname(QString hostname);
    void setUsername(QString username);
    void setPassword(QString password);
    void setPort(int port);
    void setDatabase(QString dbname);
    void setTable(QString table);
    void setSavePassword(bool savepass);
    void setDriver(QString driver);
    void setMap(QMap<QString,AddresseeTypes::Types> map);
    void setAutogenerate(bool gen);
    void setMultipleKabcFields(QList<AddresseeTypes::Types> fields);
    void setReadOnly(bool mode);
    void setTypeAttributesMap( QMap<AddresseeTypes::Types, struct typeattributes> map);
    void setResourceName( QString resourcename );
    QString hostname();
    QString username();
    QString password();
    int port();
    QString database();
    QString table();
    bool savePassword();
    QString driver();
    QMap<QString, AddresseeTypes::Types> map();
    bool autogenerate();
    bool readOnly();
    QString resourceName();
    
    
  protected:
    QSqlDatabase db;
    void openDataBase();
    QMap<QString, QString> origmap;
    QList<AddresseeTypes::Types> MultipleFields;
    QStringList KabcFieldsNameList;
    QList<QLabel *> DatabaseFieldsList;
    QList<QComboBox *> KabcFieldsList;
    QString LastChangedItem;
    QMap <AddresseeTypes::Types, struct typeattributes> TypeAttributesMap;



    
    
  protected slots:
    void driverChanged(QString sqldriver);
    void connectButtonclicked();
    void tableChanged(QString table);
    void createTable();
    void kabcIndexChanged(int index);

  private:
    Ui::ConfigDialog ui;

};

#endif // CONFIGDIALOG_H
